@@ -7,26 +7,18 @@
 # @Software: PyCharm
 import nonebot
 from nonebot import on_command, logger
-from nonebot.adapters.cqhttp import Bot, GroupMessageEvent
-from nonebot.adapters.cqhttp.exception import ActionFailed
-from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, MessageEvent
+from nonebot.adapters.onebot.v11.exception import ActionFailed
+from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
 from nonebot.permission import SUPERUSER
 from . import approve
-from .utils import At, banSb, init
+from .utils import At, banSb
 from .group_request_verify import verify
 from os.path import dirname
 
 nonebot.load_plugins(dirname(__file__))
 su = nonebot.get_driver().config.superusers
 
-admin_init = on_command("群管初始化", priority=1, block=True)
-
-
-@admin_init.handle()
-async def _(bot: Bot):
-    await init()
-
-
 ban = on_command('禁', priority=1, block=True, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
 
 
@@ -188,7 +180,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) and 'all' not in sb:
+        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_special_title(
@@ -217,7 +209,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) and 'all' not in sb:
+        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_kick(
@@ -245,7 +237,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) and 'all' not in sb:
+        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_kick(
@@ -276,7 +268,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     logger.info(sb)
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) and 'all' not in sb:
+        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_admin(
@@ -308,7 +300,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     logger.info(sb)
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) and 'all' not in sb:
+        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_admin(
