@@ -116,7 +116,7 @@ async def replace_tmr(msg: str) -> str:
     """
 
     :param msg: 消息字符串
-    :return: 去除cq码、链接等的消息字符串
+    :return: 去除cq码、链接等的
     """
     find_cq = re.compile(r"(\[CQ:.*])")
     find_link = re.compile("(https?://.*[^\u4e00-\u9fa5])")
